// Fetch data from the CSV file
d3.csv(
  'https://gist.githubusercontent.com/Prathi0410/46d02f90deac8ae8c843c7c4fef9d0a8/raw/a26ae0e5e3fa187d17001c17ac426689589873b8/ICE6-Assignment%2520Data-final',
)
  .then(function (data) {
    // Convert numerical values from strings to numbers
    data.forEach(function (d) {
      d.SalesVolume = +d.SalesVolume;
    });

    // Set up the SVG canvas dimensions
    var margin = {
        top: 40,
        right: 20,
        bottom: 100,
        left: 50,
      },
      width = 800 - margin.left - margin.right,
      height = 400 - margin.top - margin.bottom;

    // Create SVG element
    var svg = d3
      .select('#chart')
      .append('svg')
      .attr('width', width + margin.left + margin.right)
      .attr('height', height + margin.top + margin.bottom)
      .append('g')
      .attr(
        'transform',
        'translate(' + margin.left + ',' + margin.top + ')',
      );

    // Set up the X and Y scales
    var x = d3
      .scaleBand()
      .range([0, width])
      .domain(
        data.map(function (d) {
          return d.Name;
        }),
      )
      .padding(0.1);

    var y = d3
      .scaleLinear()
      .range([height, 0])
      .domain([
        0,
        d3.max(data, function (d) {
          return d.SalesVolume;
        }),
      ]);

    // Draw the bars
    svg
      .selectAll('.bar')
      .data(data)
      .enter()
      .append('rect')
      .attr('class', 'bar')
      .attr('x', function (d) {
        return x(d.Name);
      })
      .attr('width', x.bandwidth())
      .attr('y', function (d) {
        return y(d.SalesVolume);
      })
      .attr('height', function (d) {
        return height - y(d.SalesVolume);
      });

    // Add X axis
    svg
      .append('g')
      .attr('transform', 'translate(0,' + height + ')')
      .call(d3.axisBottom(x))
      .selectAll('text')
      .attr('transform', 'rotate(-45)')
      .style('text-anchor', 'end');

    // Add X axis label
    svg
      .append('text')
      .attr(
        'transform',
        'translate(' +
          width / 2 +
          ' ,' +
          (height + margin.top + 50) +
          ')',
      )
      .style('text-anchor', 'middle')
      .text('Coffee Shop Menu');

    // Add Y axis
    svg.append('g').call(d3.axisLeft(y));

    // Add Y axis label
    svg
      .append('text')
      .attr('transform', 'rotate(-90)')
      .attr('y', 0 - margin.left)
      .attr('x', 0 - height / 2)
      .attr('dy', '1em')
      .style('text-anchor', 'middle')
      .text('Sales Volume');

    // Add title
    svg
      .append('text')
      .attr('class', 'title')
      .attr('x', width / 2)
      .attr('y', 0 - margin.top / 2)
      .attr('text-anchor', 'middle')
      .style('font-size', '20px')
      .style('text-decoration', 'underline')
      .text('Sales Volume of Coffees');
  })
  .catch(function (error) {
    console.log('Error fetching the data: ', error);
  });
